@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id: ct_card.c 344 2007-01-14 22:47:54Z martin $
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -452,7 +449,8 @@ int LC_Crypt_Token__EnterPin(GWEN_CRYPT_TOKEN *ct,
   }
 
   if ((pt!=GWEN_Crypt_PinType_Manage) &&
-      (LC_Card_GetReaderFlags(hcard) & LC_READER_FLAGS_KEYPAD)) {
+      (LC_Card_GetReaderFlags(hcard) & LC_READER_FLAGS_KEYPAD) &&
+      !(GWEN_Crypt_Token_GetModes(ct) & GWEN_CRYPT_TOKEN_MODE_FORCE_PIN_ENTRY)) {
     uint32_t bid;
     int triesLeft=-1;
 
