@@ -1,9 +1,6 @@
 /***************************************************************************
- $RCSfile$
-                             -------------------
-    cvs         : $Id$
     begin       : Mon Mar 01 2004
-    copyright   : (C) 2004 by Martin Preuss
+    copyright   : (C) 2004-2010 by Martin Preuss
     email       : martin@libchipcard.de
 
  ***************************************************************************
@@ -919,7 +916,7 @@ int LC_MsgEngine_BinTypeRead(GWEN_MSGENGINE *e,
 
     DBG_VERBOUS(LC_LOGDOMAIN, "Entering BinTypeRead with this:");
     if (GWEN_Logger_GetLevel(0)>=GWEN_LoggerLevel_Verbous)
-      GWEN_Buffer_Dump(vbuf, stderr, 2);
+      GWEN_Buffer_Dump(vbuf, 2);
 
     p=GWEN_Buffer_GetStart(vbuf);
     pos=0;
